@@ -2,4 +2,4 @@
 
 from lollmsvectordb.vectorizer import Vectorizer
 from lollmsvectordb.vectorizers.tfidf_vectorizer import TFIDFVectorizer
-from lollmsvectordb.vectorizers.word2vec_vectorizer import Word2VecVectorizer
+#from lollmsvectordb.vectorizers.word2vec_vectorizer import Word2VecVectorizer
